@@ -8,7 +8,7 @@ use warnings;
 
 package Mail::Message::Body;
 use vars '$VERSION';
-$VERSION = '2.084';
+$VERSION = '2.085';
 
 use base 'Mail::Reporter';
 
@@ -18,6 +18,10 @@ use MIME::Types;
 use File::Basename 'basename';
 use Encode         'find_encoding';
 
+# http://www.iana.org/assignments/character-sets
+use Encode::Alias;
+define_alias(qr/^unicode-?1-?1-?utf-?([78])$/i => '"UTF-$1"');  # rfc1642
+
 my $mime_types;
 
 
@@ -54,8 +58,6 @@ sub encode(@)
     #
     # The only translations implemented now is content transfer encoding.
     #
-#warn "TranferEncoding ($trans_was) -> ($trans_to)\n";
-#warn "Charset ($char_was) -> ($char_to)\n";
 
     return $self
         if   $trans_was eq   $trans_to
@@ -75,10 +77,8 @@ sub encode(@)
         return $self;
     }
 
-    my $recoded;
-    if(lc($char_was) eq lc($char_to))
-    {   $recoded = $decoded;
-    }
+    my $recoded = $decoded;
+    if(lc($char_was) eq lc($char_to)) { ; }
     elsif($char_was eq 'PERL')   
     {   if(my $recoder = find_encoding $char_to)
         {   $recoded = $bodytype->new
@@ -104,11 +104,9 @@ sub encode(@)
         my $to   = find_encoding $char_to;
         if(!$from)
         {   $self->log(WARNING => "Charset `$char_was' is not known.");
-            $recoded = $decoded;
         }
         elsif(!$to)
         {   $self->log(WARNING => "Charset `$char_to' is not known.");
-            $recoded = $decoded;
         }
         else
         {   $recoded = $bodytype->new
