@@ -7,7 +7,7 @@ use warnings;
 
 package Mail::Message::Field::Full;
 use vars '$VERSION';
-$VERSION = '2.084';
+$VERSION = '2.085';
 
 use base 'Mail::Message::Field';
 
@@ -258,13 +258,17 @@ sub encode($@)
 }
 
 
-sub _decoder($$$)
-{   my ($charset, $encoding, $encoded) = @_;
+sub _decoder($$$$)
+{   my ($charset, $encoding, $encoded, $whole) = @_;
     $charset   =~ s/\*[^*]+$//;   # string language, not used
-    $charset ||= 'us-ascii';
+    my $to_utf8 = Encode::find_encoding($charset || 'us-ascii')
+        or return $whole;
 
     my $decoded;
-    if(lc($encoding) eq 'q')
+    if($encoding !~ /\S/)
+    {   $decoded = $encoded;
+    }
+    elsif(lc($encoding) eq 'q')
     {   # Quoted-printable encoded
         $encoded =~ s/_/ /g;
         $decoded = MIME::QuotedPrint::decode_qp($encoded);
@@ -276,10 +280,10 @@ sub _decoder($$$)
     }
     else
     {   # unknown encodings ignored
-        return $encoded;
+        return $whole;
     }
 
-    Encode::decode($charset, $decoded, 0);
+    $to_utf8->decode($decoded, Encode::FB_DEFAULT);  # error-chars -> '?'
 }
 
 sub decode($@)
@@ -289,7 +293,8 @@ sub decode($@)
        # dirty trick to get this done: add an explicit blank.
        $encoded =~ s/\?\=\s(?!\s*\=\?|$)/_?= /gs;
     }
-    $encoded =~ s/\=\?([^?\s]*)\?([^?\s]*)\?([^?\s]*)\?\=\s*/_decoder($1,$2,$3)/gse;
+    $encoded =~ s/\=\?([^?\s]*)\?([^?\s]*)\?([^?\s]*)\?\=\s*/
+                  _decoder($1,$2,$3,$encoded)/gse;
 
     $encoded;
 }
